![enodo logo](https://github.com/transceptor-technology/siridb-enodo-hub/raw/development/assets/logo_full.png)

*NOTE: The SiriDB Enodo platform is still in Beta. Missing documentation and examples will be added over time*

# SiriDB Enodo Lib
This library is used for the SiriDB Enodo platform for internal communication. When setting up the [Hub](https://github.com/SiriDB/siridb-enodo-hub), [Worker](https://github.com/SiriDB/siridb-enodo-worker) and [Listener](https://github.com/SiriDB/siridb-enodo-listener) this lib is used. 

The library enholds the protocol settings, package id's and package data formats by models